@@ -4,7 +4,6 @@ Created on Sun Nov 11 21:46:35 2012
 
 @author: r_milk01
 """
-from ConfigParser import (RawConfigParser as ConfigParser, NoOptionError)
 import jinja2
 from datetime import datetime
 import sys
@@ -14,12 +13,7 @@ import logging
 import itertools
 import subprocess
 from git import DiffIndex
-
-class Config(ConfigParser):
-    
-    def __getitem__(self, key):
-        section, key = key.split('.')
-        return self.get(section, key)
+import config
 
 class FileDiff(object):
     def __init__(self, diff_index):
@@ -50,27 +44,35 @@ def _get_diffs(old_rev, new_rev, rev_name, cfg):
 def format_message(module, diffs, commits, old_rev, new_rev, rev_name, cfg):
     branch = rev_name.split('/')[-1]
     project = os.path.basename(cfg['general.repo_path'])
+    projectname = cfg['general.projectname']
     counts = dict()
     for i in ['new', 'deleted', 'renamed', 'changed']:
         counts[i] = len([f for f in diffs if f.cat == i])
     statstring = ' | '.join(['%d %s'%(u, h) for h,u in counts.iteritems()])
-    try:
-        header_tpl = jinja2.Template(cfg['%s.header'%module])
-    except NoOptionError as e:
-        header_tpl = jinja2.Template(cfg['general.header'])
-    try:
-        body_tpl = jinja2.Template(cfg['%s.body'%module])
-    except NoOptionError as f:
-        body_tpl = jinja2.Template(cfg['general.body'])
     date = datetime.now()
+    
     shortlog = subprocess.check_output(['git', 'log', '--shortstat', 
                                         '--pretty=format:{}, {}%n%cn: %s%n%b'.format(project, branch),
                                         '{}...{}'.format(old_rev, new_rev) ])
+    try:
+        link_tpl = jinja2.Template(cfg['%s.link'%module])
+    except config.NoOptionError as e:
+        link_tpl = jinja2.Template(cfg['general.link'])
+    link = link_tpl.render(locals())
+    
+    try:
+        header_tpl = jinja2.Template(cfg['%s.header'%module])
+    except config.NoOptionError as e:
+        header_tpl = jinja2.Template(cfg['general.header'])
+    try:
+        body_tpl = jinja2.Template(cfg['%s.body'%module])
+    except config.NoOptionError as f:
+        body_tpl = jinja2.Template(cfg['general.body'])
     
     return header_tpl.render(locals()), body_tpl.render(locals())
 
 def notify(old_rev, new_rev, rev_name, config_file=None):
-    cfg = Config()
+    cfg = config.Config()
     used = cfg.read([os.path.expanduser('~/.gitnotifs'), config_file])
     logging.debug('using %s as config'%used)
     diffs, commits = _get_diffs(old_rev, new_rev, rev_name, cfg)
